==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/web/ReactComponent.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:29.030Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.ReactComponent")
public class ReactComponent extends io.github.cdklabs.projen.Component {

    protected ReactComponent(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ReactComponent(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public ReactComponent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.web.ReactComponentOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.ReactComponent}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.ReactComponent> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private final io.github.cdklabs.projen.web.ReactComponentOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.web.ReactComponentOptions.Builder();
        }

        /**
         * (experimental) Rewire webpack configuration.
         * <p>
         * Use this property to override webpack configuration properties provided
         * by create-react-app, without needing to eject.
         * <p>
         * This property will create a <code>config-overrides.js</code> file in your root directory,
         * which will contain the desired rewiring code.
         * <p>
         * To <strong>override</strong> the configuration, you can provide simple key value pairs.
         * Keys take the form of js code directives that traverse to the desired property.
         * Values should be JSON serializable objects.
         * <p>
         * For example, the following config:
         * <p>
         * <blockquote><pre>
         * rewire: { "module.unknownContextCritical": false }
         * </pre></blockquote>
         * <p>
         * Will translate to the following <code>config-overrides.js</code> file:
         * <p>
         * <blockquote><pre>
         * module.exports = function override(config, env) {
         *    config.module.unknownContextCritical = false;
         * }
         * </pre></blockquote>
         * <p>
         * Default: - No rewired config.
         * <p>
         * @return {@code this}
         * @see https://github.com/timarney/react-app-rewired
         * @param rewire Rewire webpack configuration. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder rewire(final java.util.Map<java.lang.String, ? extends java.lang.Object> rewire) {
            this.options.rewire(rewire);
            return this;
        }

        /**
         * (experimental) Whether to apply options specific for TypeScript React projects.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param typescript Whether to apply options specific for TypeScript React projects. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder typescript(final java.lang.Boolean typescript) {
            this.options.typescript(typescript);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.web.ReactComponent}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.ReactComponent build() {
            return new io.github.cdklabs.projen.web.ReactComponent(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/web/ReactComponent.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.728Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.ReactComponent")
public class ReactComponent extends io.github.cdklabs.projen.Component {

    protected ReactComponent(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ReactComponent(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public ReactComponent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.web.ReactComponentOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.ReactComponent}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.ReactComponent> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private final io.github.cdklabs.projen.web.ReactComponentOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.web.ReactComponentOptions.Builder();
        }

        /**
         * (experimental) Rewire webpack configuration.
         * <p>
         * Use this property to override webpack configuration properties provided
         * by create-react-app, without needing to eject.
         * <p>
         * This property will create a <code>config-overrides.js</code> file in your root directory,
         * which will contain the desired rewiring code.
         * <p>
         * To <strong>override</strong> the configuration, you can provide simple key value pairs.
         * Keys take the form of js code directives that traverse to the desired property.
         * Values should be JSON serializable objects.
         * <p>
         * For example, the following config:
         * <p>
         * <blockquote><pre>
         * rewire: { "module.unknownContextCritical": false }
         * </pre></blockquote>
         * <p>
         * Will translate to the following <code>config-overrides.js</code> file:
         * <p>
         * <blockquote><pre>
         * module.exports = function override(config, env) {
         *   config.module.unknownContextCritical = false;
         * }
         * </pre></blockquote>
         * <p>
         * Default: - No rewired config.
         * <p>
         * @return {@code this}
         * @see <a href="https://github.com/timarney/react-app-rewired">https://github.com/timarney/react-app-rewired</a>
         * @param rewire Rewire webpack configuration. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder rewire(final java.util.Map<java.lang.String, ? extends java.lang.Object> rewire) {
            this.options.rewire(rewire);
            return this;
        }

        /**
         * (experimental) Whether to apply options specific for TypeScript React projects.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param typescript Whether to apply options specific for TypeScript React projects. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder typescript(final java.lang.Boolean typescript) {
            this.options.typescript(typescript);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.web.ReactComponent}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.ReactComponent build() {
            return new io.github.cdklabs.projen.web.ReactComponent(
                this.project,
                this.options.build()
            );
        }
    }
}
